package com.caimei365.commodity.controller;

import com.caimei365.commodity.service.SearchQueryService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.util.Map;

/**
 * 搜索查询（阿里云搜索）
 *
 * @author : Charles
 * @date : 2021/4/6
 */
@Api(tags="搜索查询API")
@RestController
@RequiredArgsConstructor
@RequestMapping("/commodity/search/query")
public class SearchQueryApi {

    private final SearchQueryService searchQueryService;

    /**
     * 根据文档Id获取索引Id
     *
     * spi旧接口：/search/query/(id,pid,sid,eid,aid)
     * @return int
     */
    @ApiOperation("根据文档Id获取索引Id")
    @ApiImplicitParams({
        @ApiImplicitParam(required = false, name = "docType", value = "文档类型（product,shop,equipment,article）"),
        @ApiImplicitParam(required = false, name = "docId", value = "文档Id")
    })
    @GetMapping("id")
    public Integer getIdByDocId(String docType, Integer docId) {
        return searchQueryService.getIdByDocId(docType, docId);
    }

    /**
     * 根据文档类型获取索引Id集合
     *
     * spi旧接口：/search/query/(product,supplier,equipment,article)/ids
     * @return map
     */
    @ApiOperation("根据文档类型获取索引Id集合")
    @ApiImplicitParams({
        @ApiImplicitParam(required = true, name = "docType", value = "文档类型（product,shop,equipment,article）"),
        @ApiImplicitParam(required = false, name = "pageNum", value = "页码"),
        @ApiImplicitParam(required = false, name = "pageSize", value = "每页数量")
    })
    @GetMapping("ids")
    public Map<Integer, Integer> getMainIdsByDocType(String docType,
                                                     @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                     @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        return searchQueryService.getMainIdsByDocType(docType, pageNum, pageSize);
    }

    /**
     * 根据文档类型获取数量
     *
     * spi旧接口：/search/query/record
     * @return int
     */
    @ApiOperation("根据文档类型获取数量")
    @ApiImplicitParam(required = true, name = "docType", value = "文档类型（product,shop,equipment,article）")
    @GetMapping("record")
    public Integer getRecordByDocType(String docType) {
        return searchQueryService.getRecordByDocType(docType);
    }

    /**
     * 根据文档类型获取数量(去重用)
     *
     * spi旧接口：/search/query/acount
     * @return int
     */
    @ApiOperation("根据文档Id获取数量(去重用)")
    @ApiImplicitParams({
        @ApiImplicitParam(required = false, name = "docType", value = "文档类型（product,shop,equipment,article）"),
        @ApiImplicitParam(required = false, name = "docId", value = "文档Id")
    })
    @GetMapping("count")
    public Integer getCountByDocId(String docType, Integer docId) {
        return searchQueryService.getCountByDocId(docType, docId);
    }


}
